# Docs

## Activate the Docs Environment

```bash
hatch -e docs shell
```

## Create the MkDocs Project

```bash
mkdocs new .
```

## Build the Site

```bash
hatch run build
```
## Serve the Site

```bash
hatch run serve
```